@@ -17,13 +17,6 @@
 #endif
 
 
-#ifndef HAVE_GAI_STRERROR
-/** stub */
-#ifndef gai_strerror
-#define gai_strerror(err) "?"
-#endif
-#endif
-
 /** Length of IPv4 address string */
 #ifndef INET_ADDRSTRLEN
 #define INET_ADDRSTRLEN 16
@@ -47,6 +40,7 @@ struct sa;
 
 /* Net generic */
 int  net_hostaddr(int af, struct sa *ip);
+int  net_dst_source_addr_get(struct sa *dst, struct sa *ip);
 int  net_default_source_addr_get(int af, struct sa *ip);
 int  net_default_gateway_get(int af, struct sa *gw);
 
@@ -109,20 +103,6 @@ int net_rt_default_get(int af, char *ifname, size_t size);
 int net_rt_debug(struct re_printf *pf, void *unused);
 
 
-/* Network connection */
-
-/**
- * Defines the network connection handler
- *
- * @param err  Error code
- * @param id   Associated ID
- */
-typedef void (net_conn_h)(int err, uint32_t id);
-
-int  net_conn_start(net_conn_h *ch, uint32_t id, bool prompt);
-void net_conn_stop(void);
-
-
 /* Net strings */
 const char *net_proto2name(int proto);
 const char *net_af2name(int af);
